@@ -1,5 +1,5 @@
 /* Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0 */
-/* For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt */
+/* For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt */
 
 /* C-based Tracer for coverage.py. */
 
@@ -137,23 +137,25 @@ static void
 CTracer_showlog(CTracer * self, int lineno, PyObject * filename, const char * msg)
 {
     if (logging) {
+        FILE *flog = fopen("/tmp/debug_trace.txt", "a");
         int depth = self->pdata_stack->depth;
-        printf("%x: %s%3d ", (int)self, indent(depth), depth);
+        fprintf(flog, "%p: %s%3d ", self, indent(depth), depth);
         if (lineno) {
-            printf("%4d", lineno);
+            fprintf(flog, "%4d", lineno);
         }
         else {
-            printf("    ");
+            fprintf(flog, "    ");
         }
         if (filename) {
             PyObject *ascii = PyUnicode_AsASCIIString(filename);
-            printf(" %s", PyBytes_AS_STRING(ascii));
+            fprintf(flog, " %s", PyBytes_AS_STRING(ascii));
             Py_DECREF(ascii);
         }
         if (msg) {
-            printf(" %s", msg);
+            fprintf(flog, " %s", msg);
         }
-        printf("\n");
+        fprintf(flog, "\n");
+        fclose(flog);
     }
 }
 
@@ -182,14 +184,14 @@ CTracer_record_pair(CTracer *self, int l1, int l2)
     // the two line numbers into one integer instead.
     // See collector.py:flush_data for the Python code that unpacks this.
     if (l1 < 0) {
-        packed |= (1LL << 40);
+        packed |= (1LL << 56);
         l1 = -l1;
     }
     if (l2 < 0) {
-        packed |= (1LL << 41);
+        packed |= (1LL << 57);
         l2 = -l2;
     }
-    packed |= (((uint64)l2) << 20) + (uint64)l1;
+    packed |= (((uint64)l2) << 28) + (uint64)l1;
     packed_obj = PyLong_FromUnsignedLongLong(packed);
     if (packed_obj == NULL) {
         goto error;
